/***************************************************************************
*   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#include "fieldtype.h"

namespace bit
  {
    
    const char* FieldType::m_type_string[] = {
      "None",
      "Integer",
      "Floating Point",
      "ASCII",
      "BCD (Binary Coded Decimal)",
      "UTF8",
    };

    const char* FieldType::m_byte_order_string[] = {
      "Network",
      "Big Endian",
      "Little Endian",
    };

    const char* FieldType::m_sign_string[] = {
      "Unsigned",
      "Two's Complement",
      "One's Complement",
      "Sign Bit",
    };

    const char* FieldType::type_string(Type type) {
      return m_type_string[type];
    }

    const char* FieldType::byte_order_string(ByteOrder byteorder) {
      return m_byte_order_string[byteorder];
    }

    const char* FieldType::sign_string(Sign sign) {
      return m_sign_string[sign];
    }

  FieldType::FieldType(Type type, ByteOrder byte_order, Sign sign):
      m_type(type),
      m_byte_order(byte_order),
      m_sign(sign)
  {}


  FieldType::~FieldType()
  {}


      Type FieldType::type() const
    {
      return m_type;
    }

  void FieldType::set_type(Type type)
  {
    m_type = type;
  }

  const char* FieldType::type_string() const {
    return type_string( m_type );
  }

  ByteOrder FieldType::byte_order() const
    {
      return m_byte_order;
    }

  void FieldType::set_byte_order(ByteOrder byte_order)
  {
    m_byte_order = byte_order;
  }

  const char* FieldType::byte_order_string() const {
    return byte_order_string(m_byte_order);
  }

  Sign FieldType::sign() const
    {
      return m_sign;
    }

  void FieldType::set_sign(Sign sign)
  {
    m_sign = sign;
  }

  const char* FieldType::sign_string() const {
    return sign_string(m_sign);
  }

  }
